@@ -79,7 +79,7 @@ create_windows_from_cmdline(gpointer data)
 
         if(files)
                 for(i = 0; files[i]; i++) {
-                        if(strchr(files[i], ':') != NULL) {
+                        if(strstr(files[i], "://") != NULL) {
                                 /* this seems like an URI */
                                 create_window(files[i]);
                         }
@@ -231,6 +231,9 @@ main(int argc, char **argv)
 
         gtk_idle_add (create_windows_from_cmdline, &ctx);
 
+	/*Init Stock Icons*/
+	ggv_init_stock_icons ();
+
 	gnome_window_icon_set_default_from_file (GNOMEICONDIR "/gnome-ghostview.png");
 
         ggv_prefs_load();
@@ -265,7 +268,13 @@ main(int argc, char **argv)
                 g_free(filename_stdin);
         }
 
-        ggv_prefs_save();
+        if(ggv_save_geometry) {
+                GConfClient *gconf_client = ggv_prefs_gconf_client();
+                gconf_client_set_int(gconf_client, "/apps/ggv/layout/windowwidth",
+                                     ggv_default_width, NULL);
+                gconf_client_set_int(gconf_client, "/apps/ggv/layout/windowheight",
+                                     ggv_default_height, NULL);
+        }
 
 	CORBA_exception_free (&ev);
 	
